.. execo documentation master file, created by
   sphinx-quickstart on Sat Jan 16 23:29:37 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to execo
================

Execo is a Python library that allows you to finely manage unix
processes on thousands of remote hosts.  It is well designed for:

- prototyping experiments on distributed systems

- automatize admin tasks

- create reproducible experiments

Contents:

.. toctree::
   :maxdepth: 2

   Readme <readme>
   User Guide <userguide>
   API Documentation <apidoc>
   FAQ <faq>
   Miscellaneous <misc>
   Python2 / Python3 <python2-python3>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
